==> liquidwar-5.5.3.tar.gz: liquidwar-5.5.3/src/rules.c <==
/********************************************************************/
/*                                                                  */
/*            L   I  QQ  U U I DD    W   W  A  RR    555            */
/*            L   I Q  Q U U I D D   W   W A A R R   5              */
/*            L   I Q  Q U U I D D   W W W AAA RR    55             */
/*            L   I Q Q  U U I D D   WW WW A A R R     5            */
/*            LLL I  Q Q  U  I DD    W   W A A R R   55             */
/*                                                                  */
/*                             b                                    */
/*                             bb  y y                              */
/*                             b b yyy                              */
/*                             bb    y                              */
/*                                 yy                               */
/*                                                                  */
/*                     U U       FFF  O   O  TTT                    */
/*                     U U       F   O O O O  T                     */
/*                     U U TIRET FF  O O O O  T                     */
/*                     U U       F   O O O O  T                     */
/*                      U        F    O   O   T                     */
/*                                                                  */
/********************************************************************/

/*****************************************************************************/
/* Liquid War is a unique multiplayer wargame                                */
/* Copyright (C) 1998-2002 Christian Mauduit                                 */
/*                                                                           */
/* This program is free software; you can redistribute it and/or modify      */
/* it under the terms of the GNU General Public License as published by      */
/* the Free Software Foundation; either version 2 of the License, or         */
/* (at your option) any later version.                                       */
/*                                                                           */
/* This program is distributed in the hope that it will be useful,           */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
/* GNU General Public License for more details.                              */
/*                                                                           */
/* You should have received a copy of the GNU General Public License         */
/* along with this program; if not, write to the Free Software               */
/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
/*                                                                           */
/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
/* Contact author      : ufoot@ufoot.org                                     */
/*****************************************************************************/

/********************************************************************/
/* nom           : rules.c                                          */
/* contenu       : choix des regles de jeu                          */
/* date de modif : 3 mai 98                                         */
/********************************************************************/

/*==================================================================*/
/* includes                                                         */
/*==================================================================*/

#include <string.h>
#include <stdio.h>

#include "advanced.h"
#include "config.h"
#include "dialog.h"
#include "disk.h"
#include "help.h"
#include "menu.h"
#include "rules.h"
#include "sound.h"
#include "time.h"
#include "lang.h"

/*==================================================================*/
/* variables globales                                               */
/*==================================================================*/

/*==================================================================*/
/* fonctions                                                        */
/*==================================================================*/

/*------------------------------------------------------------------*/
static void write_time_setting (DIALOG *d)
{
  char *str;

  str=d->dp;
  start_play_time();
  write_time (TIME_LEFT,str+8);
}

/*------------------------------------------------------------------*/
static int slider_time (void *dp3, int d2)
{
  DIALOG *d;

  d=dp3;

  CONFIG_GAME_TIME=d2;
  write_time_setting (d);

  scare_mouse();
  my_textbox_proc (MSG_DRAW, d, 0);
  unscare_mouse();

  play_click ();

  return 0;
}

/*------------------------------------------------------------------*/
int rules_options (void)
{
  int *temp;
  DIALOG d[10];
  int i,choix=4,retour=0;
  static int y_pos[3]={0,1,3};
  char time_str[14];
  
  memset(d,0,sizeof(d));

  sprintf(time_str,"%-8s00:00",lw_lang_string(LW_LANG_STRING_RULES_TIME));

  for (i=0; i<2; ++i)
    {
      standard_button (d+i+4,0,y_pos[i],2,4);
      d[i+4].proc=my_textbox_proc;
    }
  for (i=0; i<2; ++i)
    {
      standard_button (d+i+6,1,y_pos[i],2,4);
      d[i+6].proc=my_slider_proc;
    }

  standard_button (d+8,0,3,1,4);
  d[8].dp=lw_lang_string(LW_LANG_STRING_RULES_ADVANCED);

  quick_buttons(d);
  d[4].dp=lw_lang_string(LW_LANG_STRING_RULES_ARMYSIZE);
  d[5].dp=time_str;
  d[6].d1=32;
  d[7].d1=16;
  d[6].dp3=&CONFIG_FIGHTER_NUMBER;
  d[7].dp3=&CONFIG_GAME_TIME;
  for (i=6;i<8;++i)
    {
      d[i].dp=NULL;
      d[i].dp2=slider_int;
      temp=d[i].dp3;
      d[i].d2=*temp;
    }
  d[7].dp2=slider_time;
  d[7].dp3=d+5;
  write_time_setting (d+5);
 
  d[9].proc=0;

  while (retour==0)
    {
      choix=my_do_dialog (d,choix);
      switch (choix)
	{
	case -1:
	case MENU_QUICK_BACK:
	  retour=1;
	  break;
	case MENU_QUICK_MAIN:
	  retour=MENU_TOP;
	  break;
	case MENU_QUICK_QUIT:
	  if (confirm_quit())
	    retour=MENU_EXIT;
	  break;
	case MENU_QUICK_PLAY:
	  retour=MENU_PLAY;
	  break;
	case 8 :
	  retour=advanced_options();
	  break;
	}
    }

  if (retour>0)
    retour--;

  return retour;
}

==> liquidwar-5.5.4.tar.gz: liquidwar-5.5.4/src/rules.c <==
/********************************************************************/
/*                                                                  */
/*            L   I  QQ  U U I DD    W   W  A  RR    555            */
/*            L   I Q  Q U U I D D   W   W A A R R   5              */
/*            L   I Q  Q U U I D D   W W W AAA RR    55             */
/*            L   I Q Q  U U I D D   WW WW A A R R     5            */
/*            LLL I  Q Q  U  I DD    W   W A A R R   55             */
/*                                                                  */
/*                             b                                    */
/*                             bb  y y                              */
/*                             b b yyy                              */
/*                             bb    y                              */
/*                                 yy                               */
/*                                                                  */
/*                     U U       FFF  O   O  TTT                    */
/*                     U U       F   O O O O  T                     */
/*                     U U TIRET FF  O O O O  T                     */
/*                     U U       F   O O O O  T                     */
/*                      U        F    O   O   T                     */
/*                                                                  */
/********************************************************************/

/*****************************************************************************/
/* Liquid War is a unique multiplayer wargame                                */
/* Copyright (C) 1998-2002 Christian Mauduit                                 */
/*                                                                           */
/* This program is free software; you can redistribute it and/or modify      */
/* it under the terms of the GNU General Public License as published by      */
/* the Free Software Foundation; either version 2 of the License, or         */
/* (at your option) any later version.                                       */
/*                                                                           */
/* This program is distributed in the hope that it will be useful,           */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
/* GNU General Public License for more details.                              */
/*                                                                           */
/* You should have received a copy of the GNU General Public License         */
/* along with this program; if not, write to the Free Software               */
/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
/*                                                                           */
/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
/* Contact author      : ufoot@ufoot.org                                     */
/*****************************************************************************/

/********************************************************************/
/* nom           : rules.c                                          */
/* contenu       : choix des regles de jeu                          */
/* date de modif : 3 mai 98                                         */
/********************************************************************/

/*==================================================================*/
/* includes                                                         */
/*==================================================================*/

#include <string.h>
#include <stdio.h>

#include "advanced.h"
#include "config.h"
#include "dialog.h"
#include "disk.h"
#include "help.h"
#include "menu.h"
#include "rules.h"
#include "sound.h"
#include "time.h"
#include "lang.h"

/*==================================================================*/
/* variables globales                                               */
/*==================================================================*/

/*==================================================================*/
/* fonctions                                                        */
/*==================================================================*/

/*------------------------------------------------------------------*/
static void write_time_setting (DIALOG *d)
{
  char *str;

  str=d->dp;
  start_play_time();
  write_time (TIME_LEFT,str+8);
}

/*------------------------------------------------------------------*/
static int slider_time (void *dp3, int d2)
{
  DIALOG *d;

  d=dp3;

  CONFIG_GAME_TIME=d2;
  /*
   * Following line needed because start_play_time() uses the
   * value in LW_CONFIG_CURRENT_RULES
   */
  LW_CONFIG_CURRENT_RULES.game_time=CONFIG_GAME_TIME;

  write_time_setting (d);

  scare_mouse();
  my_textbox_proc (MSG_DRAW, d, 0);
  unscare_mouse();

  play_click ();

  return 0;
}

/*------------------------------------------------------------------*/
int rules_options (void)
{
  int *temp;
  DIALOG d[10];
  int i,choix=4,retour=0;
  static int y_pos[3]={0,1,3};
  char time_str[14];
  
  memset(d,0,sizeof(d));

  sprintf(time_str,"%-8s00:00",lw_lang_string(LW_LANG_STRING_RULES_TIME));

  for (i=0; i<2; ++i)
    {
      standard_button (d+i+4,0,y_pos[i],2,4);
      d[i+4].proc=my_textbox_proc;
    }
  for (i=0; i<2; ++i)
    {
      standard_button (d+i+6,1,y_pos[i],2,4);
      d[i+6].proc=my_slider_proc;
    }

  standard_button (d+8,0,3,1,4);
  d[8].dp=lw_lang_string(LW_LANG_STRING_RULES_ADVANCED);

  quick_buttons(d);
  d[4].dp=lw_lang_string(LW_LANG_STRING_RULES_ARMYSIZE);
  d[5].dp=time_str;
  d[6].d1=32;
  d[7].d1=16;
  d[6].dp3=&CONFIG_FIGHTER_NUMBER;
  d[7].dp3=&CONFIG_GAME_TIME;
  for (i=6;i<8;++i)
    {
      d[i].dp=NULL;
      d[i].dp2=slider_int;
      temp=d[i].dp3;
      d[i].d2=*temp;
    }
  d[7].dp2=slider_time;
  d[7].dp3=d+5;
  write_time_setting (d+5);
 
  d[9].proc=0;

  while (retour==0)
    {
      choix=my_do_dialog (d,choix);
      switch (choix)
	{
	case -1:
	case MENU_QUICK_BACK:
	  retour=1;
	  break;
	case MENU_QUICK_MAIN:
	  retour=MENU_TOP;
	  break;
	case MENU_QUICK_QUIT:
	  if (confirm_quit())
	    retour=MENU_EXIT;
	  break;
	case MENU_QUICK_PLAY:
	  retour=MENU_PLAY;
	  break;
	case 8 :
	  retour=advanced_options();
	  break;
	}
    }

  if (retour>0)
    retour--;

  return retour;
}
